@@ -31,13 +31,14 @@ class CommandView(MessageView):
     def register(cls, dp: Dispatcher):
         """
         """
-        callback = cls.execute
+        callback = cls._execute
         default_command = cls.__name__.lower()
         commands = cls.commands
         if not cls.commands:
             commands = [default_command]
         elif cls.append_commands:
             commands.append(default_command)
+        cls.commands = commands
 
         if cls.update_type == 'message':
             register_handler = dp.register_message_handler
